diff --git a/main.go b/main.go
index 41508da84b647d752c619765ed30f00f23cc6ee5..e6d4e05b63ad6560242ea0b7768f23ffce4c081f 100644
--- a/main.go
+++ b/main.go
@@ -149,7 +149,7 @@ func setGlobals() {
 	js.Global().Set("NewCmix", js.FuncOf(wasm.NewCmix))
 	js.Global().Set("LoadCmix", js.FuncOf(wasm.LoadCmix))
 	js.Global().Set("LoadSynchronizedCmix",
-		js.FuncOf(wasm.LoadSyncrhonizedCmix))
+		js.FuncOf(wasm.LoadSynchronizedCmix))
 
 	// wasm/delivery.go
 	js.Global().Set("SetDashboardURL", js.FuncOf(wasm.SetDashboardURL))
diff --git a/wasm_test.go b/wasm_test.go
index 59c4485c516894972b0cbcfa74b49218f28299f8..b415ece5623aa4e235511fb1f9cb24058e02e384 100644
--- a/wasm_test.go
+++ b/wasm_test.go
@@ -66,6 +66,9 @@ func TestPublicFunctions(t *testing.T) {
 
 		// Logging has been moved to startup flags
 		"LogLevel": {},
+
+		// NewFilesystemRemoteStorage is internal for bindings.
+		"NewFileSystemRemoteStorage": {},
 	}
 	wasmFuncs := getPublicFunctions("wasm", t)
 	bindingsFuncs := getPublicFunctions(
diff --git a/wasm/cmix.go b/wasm/cmix.go
index 83a76767c84878f1fd8c6df9e4faccb657510caa..c24531a0b128810638b5c15e4e3ce0c618db7817 100644
--- a/wasm/cmix.go
+++ b/wasm/cmix.go
@@ -144,7 +144,7 @@ func LoadCmix(_ js.Value, args []js.Value) any {
 	return utils.CreatePromise(promiseFn)
 }
 
 // LoadSyncrhonizedCmix will [LoadCmix] using a RemoteStore to establish
 // a synchronized RemoteKV.
 //
 // Parameters:
@@ -156,7 +156,7 @@ func LoadCmix(_ js.Value, args []js.Value) any {
 // Returns a promise:
 //   - Resolves to a Javascript representation of the [Cmix] object.
 //   - Rejected with an error if loading [Cmix] fails.
-func LoadSyncrhonizedCmix(_ js.Value, args []js.Value) any {
+func LoadSynchronizedCmix(_ js.Value, args []js.Value) any {
 	storageDir := args[0].String()
 	password := utils.CopyBytesToGo(args[1])
 	rs := newRemoteStore(args[2])
@@ -144,7 +144,7 @@ func LoadCmix(_ js.Value, args []js.Value) any {
 }
 
-// LoadSyncrhonizedCmix will [LoadCmix] using a RemoteStore to establish
+// LoadSynchronizedCmix will [LoadCmix] using a RemoteStore to establish
 // a synchronized RemoteKV.
 //